import RPi.GPIO as GPIO
import time
import sys
import math
import os

#Specify CamillaDSP configurations and what to display for each
config = ["ultralitemk5_streamer44.yml","ultralitemk5_analog48.yml", "ultralitemk5_spdif48.yml", "ultralitemk5_toslink48.yml"]
configdisplay = ["Streamer", "Analog", "SPDIF", "TOSLINK"]

# Define RPi GPIO to display mapping for 8 bit 6800 parallel
OLED_DC = 16
OLED_E = 23
OLED_D0 = 26
OLED_D1 = 13
OLED_D2 = 6
OLED_D3 = 5
OLED_D4 = 22
OLED_D5 = 27
OLED_D6 = 17
OLED_D7 = 18
OLED_RESET = 12
OLED_CS = 25

def main():

	# Claim RPi GPIO outputs
	GPIO.setmode(GPIO.BCM)
	GPIO.setup(OLED_DC, GPIO.OUT)
	GPIO.setup(OLED_E, GPIO.OUT)
	GPIO.setup(OLED_D0, GPIO.OUT)
	GPIO.setup(OLED_D1, GPIO.OUT)
	GPIO.setup(OLED_D2, GPIO.OUT)
	GPIO.setup(OLED_D3, GPIO.OUT)
	GPIO.setup(OLED_D4, GPIO.OUT)
	GPIO.setup(OLED_D5, GPIO.OUT)
	GPIO.setup(OLED_D6, GPIO.OUT)
	GPIO.setup(OLED_D7, GPIO.OUT)
	GPIO.setup(OLED_RESET, GPIO.OUT)
	GPIO.setup(OLED_CS, GPIO.OUT)

	# Reset display
	GPIO.output(OLED_RESET, 0)
	time.sleep(0.15)
	GPIO.output(OLED_RESET, 1)
	time.sleep(0.15)

	GPIO.output(OLED_DC, 1)
	GPIO.output(OLED_E, 1)


	# Initialize display
	oled_init()

	# Get CamillaDSP parameters
	global status
	global conf
	global mute
	global current

	#oled_string(0x1C,0x5A,0x04,0x1B,24,font3,"dB")
	# Counter to measure time without volume change
	count=0

	# Variable to determine if display is on (0) or off (1)
	cleared=0

	# Store current volume level
	# Continuous loop
	while True:

		# Get CamillaDSP volume level
		time.sleep(0.05)
		oled_string1()
		oled_string2()
		oled_string3()
		volume()
		dB()


# Send data to display
def data(bits):
        GPIO.output(OLED_D0, bits & 0b00000001)
        GPIO.output(OLED_D1, bits & 0b00000010)
        GPIO.output(OLED_D2, bits & 0b00000100)
        GPIO.output(OLED_D3, bits & 0b00001000)
        GPIO.output(OLED_D4, bits & 0b00010000)
        GPIO.output(OLED_D5, bits & 0b00100000)
        GPIO.output(OLED_D6, bits & 0b01000000)
        GPIO.output(OLED_D7, bits & 0b10000000)
        GPIO.output(OLED_CS, 0)
        GPIO.output(OLED_CS, 1)

# Send command to display
def command(bits):
        GPIO.output(OLED_D0, bits & 0b00000001)
        GPIO.output(OLED_D1, bits & 0b00000010)
        GPIO.output(OLED_D2, bits & 0b00000100)
        GPIO.output(OLED_D3, bits & 0b00001000)
        GPIO.output(OLED_D4, bits & 0b00010000)
        GPIO.output(OLED_D5, bits & 0b00100000)
        GPIO.output(OLED_D6, bits & 0b01000000)
        GPIO.output(OLED_D7, bits & 0b10000000)
        GPIO.output(OLED_DC, 0)
        GPIO.output(OLED_CS, 0)
        GPIO.output(OLED_CS, 1)
        GPIO.output(OLED_DC, 1)

# Set column start (a) and end (b) address, values between 28 and 91 for 128x64 SSD1322 display (2 pixels per column)
def set_column_address(a,b):
        command(0x15)
        data(a)
        data(b)

# Write to RAM
def set_write_ram():
	command(0x5C)

# Read from RAM
def set_read_ram():
	command(0x5D)

# Set row start (a) and end (b) address, values between 0 and 63 for 128x64 SSD1322 display
def set_row_address(a,b):
        command(0x75)
        data(a)
        data(b)

# Set remap, vertical increment starting in upper left: a = 0x07, b = 0x11; horizontal increment starting in upper left: a = 0x16, b = 0x11 
def set_remap(a,b):
	command(0xA0)
	data(a)
	data(b)

# Set display RAM display start line register from 0-127
def set_display_start_line(a):
	command(0xA1)
	data(a)

# Set vertical shift by COM from 0-127
def set_display_offset(a):
	command(0xA2)
	data(a)

# Set display mode
def display_mode(a):
	command(a)

# Turn on partial display mode, a = start row address, b = end row address
def enable_partial_display(a,b):
	command(0xA8)
	data(a)
	data(b)

# Exit partial display mode
def exit_partial_display():
	command(0xA9)

# Function selection, a = 0 for external VDD, a = 1 for internal VDD regulator
def function_selection(a):
	command(0xAB)
	data(a)

# Set sleep mode, a = 0xAE for sleep mode on, a = 0xAF for sleep mode off
def set_sleep_mode(a):
	command(a)

# Set phase length
def set_phase_length(a):
	command(0xB1)
	data(a)

# Set display clock divide ratio / oscillator frequency
def set_display_clock_oscillator_frequency(a):
	command(0xB3)
	data(a)

# VSL / display enhancement
def enable_external_vsl(a,b):
	command(0xB4)
	data(a)
	data(b)

# Set GPIO
def set_gpio(a):
	command(0xB5)
	data(a)

# Set second pre-charge period
def set_second_precharge_period(a):
	command(0xB6)
	data(a)

# Set grayscale table
def default_grayscale_command():
	command(0xB9)

# Set pre-charge voltage
def set_precharge_voltage(a):
	command(0xBB)
	data(a)

# Set VCOMH voltage
def set_vcomh_voltage(a):
	command(0xBE)
	data(a)

# Set contrast control, value of 1 to 256, contrast increases with higher values
def set_contrast_control(a):
	command(0xC1)
	data(a)

# Master contrast control
def master_contrast_control(a):
	command(0xC7)
	data(a)

# Set multiplex ratio
def set_multiplex_ratio(a):
	command(0xCA)
	data(a)

# Set display enhancement B
def display_enhancement(a):
	command(0xD1)
	data(a)
	data(0x20)

# Set command lock
def set_command_lock(a):
	command(0xFD)
	data(a)

# Clear display
def clearpixel():
	set_column_address(0x1C,0x5B)
	set_row_address(0x00,0x3F)
	set_write_ram()
	for i in range(8192):
			data(0x00)

def oled_string_vol(a,b,c,d,h,font,message):
	set_column_address(a,b)
	set_row_address(c,d)
	set_write_ram()
	buf=[]
	lines = math.ceil(h/8)
	mask=0x01

	for x in range(len(message)):
		if message[x]==" ":
			char=font[0]
		elif message[x]=="-":
			char=font[1]
		elif message[x]=="+":
			char=font[12]
		else:
			char=font[int(message[x])+2]
		if lines == 1:
			for i in range(int(len(char)/lines)):
					for j in range(h):
						if(((char[i] >> j)&mask)==mask):
							buf.append(1)
						else:
							buf.append(0)
		elif lines == 2:
			for i in range(int(len(char)/lines)):
					for j in range(8):
							if(((char[i] >> j)&mask)==mask):
								buf.append(1)
							else:
								buf.append(0)
					for j in range(h-8):
							if(((char[int(len(char)/lines)+i] >> j)&mask)==mask):
								buf.append(1)
							else:
								buf.append(0)

		elif lines == 3:
			for i in range(int(len(char)/lines)):
					for j in range(8):
							if(((char[i] >> j)&mask)==mask):
								buf.append(1)
							else:
								buf.append(0)
					for j in range(8):
							if(((char[int(len(char)/lines)+i] >> j)&mask)==mask):
								buf.append(1)
							else:
								buf.append(0)
					for j in range(h-16):
							if(((char[int(len(char)*2/lines)+i] >> j)&mask)==mask):
								buf.append(1)
							else:
								buf.append(0)

		elif lines == 4:
			for i in range(int(len(char)/lines)):
					for j in range(8):
							if(((char[i] >> j)&mask)==mask):
								buf.append(1)
							else:
								buf.append(0)
					for j in range(8):
							if(((char[int(len(char)/lines)+i] >> j)&mask)==mask):
								buf.append(1)
							else:
								buf.append(0)

					for j in range(8):
							if(((char[int(len(char)*2/lines)+i] >> j)&mask)==mask):
								buf.append(1)
							else:
								buf.append(0)

					for j in range(h-24):
							if(((char[int(len(char)*3/lines)+i] >> j)&mask)==mask):
								buf.append(1)
							else:
								buf.append(0)

		elif lines == 5:
			for i in range(int(len(char)/lines)):
					for j in range(8):
							if(((char[i] >> j)&mask)==mask):
								buf.append(1)
							else:
								buf.append(0)
					for j in range(8):
							if(((char[int(len(char)/lines)+i] >> j)&mask)==mask):
								buf.append(1)
							else:
								buf.append(0)

					for j in range(8):
							if(((char[int(len(char)*2/lines)+i] >> j)&mask)==mask):
								buf.append(1)
							else:
								buf.append(0)
					for j in range(8):
							if(((char[int(len(char)*3/lines)+i] >> j)&mask)==mask):
								buf.append(1)
							else:
								buf.append(0)

					for j in range(h-32):
							if(((char[int(len(char)*4/lines)+i] >> j)&mask)==mask):
								buf.append(1)
							else:
								buf.append(0)

		elif lines == 6:
			for i in range(int(len(char)/lines)):
					for j in range(8):
							if(((char[i] >> j)&mask)==mask):
								buf.append(1)
							else:
								buf.append(0)
					for j in range(8):
							if(((char[int(len(char)/lines)+i] >> j)&mask)==mask):
								buf.append(1)
							else:
								buf.append(0)

					for j in range(8):
							if(((char[int(len(char)*2/lines)+i] >> j)&mask)==mask):
								buf.append(1)
							else:
								buf.append(0)
					for j in range(8):
							if(((char[int(len(char)*3/lines)+i] >> j)&mask)==mask):
								buf.append(1)
							else:
								buf.append(0)

					for j in range(8):
							if(((char[int(len(char)*4/lines)+i] >> j)&mask)==mask):
								buf.append(1)
							else:
								buf.append(0)

					for j in range(h-40):
							if(((char[int(len(char)*5/lines)+i] >> j)&mask)==mask):
								buf.append(1)
							else:
								buf.append(0)

		elif lines == 7:
			for i in range(int(len(char)/lines)):
					for j in range(8):
							if(((char[i] >> j)&mask)==mask):
								buf.append(1)
							else:
								buf.append(0)
					for j in range(8):
							if(((char[int(len(char)/lines)+i] >> j)&mask)==mask):
								buf.append(1)
							else:
								buf.append(0)

					for j in range(8):
							if(((char[int(len(char)*2/lines)+i] >> j)&mask)==mask):
								buf.append(1)
							else:
								buf.append(0)
					for j in range(8):
							if(((char[int(len(char)*3/lines)+i] >> j)&mask)==mask):
								buf.append(1)
							else:
								buf.append(0)

					for j in range(8):
							if(((char[int(len(char)*4/lines)+i] >> j)&mask)==mask):
								buf.append(1)
							else:
								buf.append(0)

					for j in range(8):
							if(((char[int(len(char)*5/lines)+i] >> j)&mask)==mask):
								buf.append(1)
							else:
								buf.append(0)

					for j in range(h-48):
							if(((char[int(len(char)*6/lines)+i] >> j)&mask)==mask):
								buf.append(1)
							else:
								buf.append(0)

		elif lines == 8:
			for i in range(int(len(char)/lines)):
					for j in range(8):
							if(((char[i] >> j)&mask)==mask):
								buf.append(1)
							else:
								buf.append(0)
					for j in range(8):
							if(((char[int(len(char)/lines)+i] >> j)&mask)==mask):
								buf.append(1)
							else:
								buf.append(0)

					for j in range(8):
							if(((char[int(len(char)*2/lines)+i] >> j)&mask)==mask):
								buf.append(1)
							else:
								buf.append(0)
					for j in range(8):
							if(((char[int(len(char)*3/lines)+i] >> j)&mask)==mask):
								buf.append(1)
							else:
								buf.append(0)

					for j in range(8):
							if(((char[int(len(char)*4/lines)+i] >> j)&mask)==mask):
								buf.append(1)
							else:
								buf.append(0)
					for j in range(8):
							if(((char[int(len(char)*5/lines)+i] >> j)&mask)==mask):
								buf.append(1)
							else:
								buf.append(0)
					for j in range(8):
							if(((char[int(len(char)*6/lines)+i] >> j)&mask)==mask):
								buf.append(1)
							else:
								buf.append(0)
					for j in range(h-56):
							if(((char[int(len(char)*7/lines)+i] >> j)&mask)==mask):
								buf.append(1)
							else:
								buf.append(0)
	remainder = (len(buf)/h) % 4

	if remainder != 0:

		for i in range(int(h*remainder)):
			buf.append(0)

	for i in range(int((len(buf)/h)/4)):
		k=4*h*i
		for j in range(h):
			if buf[k+j]==1 and buf[k+j+h]==1:
				data(0xFF)
			elif buf[k+j]==0 and buf[k+j+h]==1:
				data(0x0F)
			elif buf[k+j]==1 and buf[k+j+h]==0:
				data(0xF0)

			else:
				data(0x00)

			if buf[k+j+2*h]==1 and buf[k+j+3*h]==1:
				data(0xFF)

			elif buf[k+j+2*h]==0 and buf[k+j+3*h]==1:
				data(0x0F)
			elif buf[k+j+2*h]==1 and buf[k+j+3*h]==0:
				data(0xF0)

			else:
				data(0x00)




def oled_string(a,b,c,d,h,font,message):
	set_column_address(a,b)
	set_row_address(c,d)
	set_write_ram()
	buf=[]
	lines = math.ceil(h/8)
	mask=0x01
	for x in range(len(message)):
		char=font[ord(message[x])-32]
		if lines == 1:
			for i in range(int(len(char)/lines)):
					for j in range(h):
						if(((char[i] >> j)&mask)==mask):
							buf.append(1)
						else:
							buf.append(0)
			for j in range(h):
				buf.append(0)
		elif lines == 2:
			for i in range(int(len(char)/lines)):
					for j in range(8):
							if(((char[i] >> j)&mask)==mask):
								buf.append(1)
							else:
								buf.append(0)
					for j in range(h-8):
							if(((char[int(len(char)/lines)+i] >> j)&mask)==mask):
								buf.append(1)
							else:
								buf.append(0)
			for j in range(2*h):
				buf.append(0)

		elif lines == 3:
			for i in range(int(len(char)/lines)):
					for j in range(8):
							if(((char[i] >> j)&mask)==mask):
								buf.append(1)
							else:
								buf.append(0)
					for j in range(8):
							if(((char[int(len(char)/lines)+i] >> j)&mask)==mask):
								buf.append(1)
							else:
								buf.append(0)
					for j in range(h-16):
							if(((char[int(len(char)*2/lines)+i] >> j)&mask)==mask):
								buf.append(1)
							else:
								buf.append(0)
			for j in range(2*h):
				buf.append(0)
		elif lines == 4:
			for i in range(int(len(char)/lines)):
					for j in range(8):
							if(((char[i] >> j)&mask)==mask):
								buf.append(1)
							else:
								buf.append(0)
					for j in range(8):
							if(((char[int(len(char)/lines)+i] >> j)&mask)==mask):
								buf.append(1)
							else:
								buf.append(0)

					for j in range(8):
							if(((char[int(len(char)*2/lines)+i] >> j)&mask)==mask):
								buf.append(1)
							else:
								buf.append(0)

					for j in range(h-24):
							if(((char[int(len(char)*3/lines)+i] >> j)&mask)==mask):
								buf.append(1)
							else:
								buf.append(0)
			for j in range(4*h):
				buf.append(0)

		elif lines == 5:
			for i in range(int(len(char)/lines)):
					for j in range(8):
							if(((char[i] >> j)&mask)==mask):
								buf.append(1)
							else:
								buf.append(0)
					for j in range(8):
							if(((char[int(len(char)/lines)+i] >> j)&mask)==mask):
								buf.append(1)
							else:
								buf.append(0)

					for j in range(8):
							if(((char[int(len(char)*2/lines)+i] >> j)&mask)==mask):
								buf.append(1)
							else:
								buf.append(0)
					for j in range(8):
							if(((char[int(len(char)*3/lines)+i] >> j)&mask)==mask):
								buf.append(1)
							else:
								buf.append(0)

					for j in range(h-32):
							if(((char[int(len(char)*4/lines)+i] >> j)&mask)==mask):
								buf.append(1)
							else:
								buf.append(0)
			for j in range(4*h):
				buf.append(0)

		elif lines == 6:
			for i in range(int(len(char)/lines)):
					for j in range(8):
							if(((char[i] >> j)&mask)==mask):
								buf.append(1)
							else:
								buf.append(0)
					for j in range(8):
							if(((char[int(len(char)/lines)+i] >> j)&mask)==mask):
								buf.append(1)
							else:
								buf.append(0)

					for j in range(8):
							if(((char[int(len(char)*2/lines)+i] >> j)&mask)==mask):
								buf.append(1)
							else:
								buf.append(0)
					for j in range(8):
							if(((char[int(len(char)*3/lines)+i] >> j)&mask)==mask):
								buf.append(1)
							else:
								buf.append(0)

					for j in range(8):
							if(((char[int(len(char)*4/lines)+i] >> j)&mask)==mask):
								buf.append(1)
							else:
								buf.append(0)

					for j in range(h-40):
							if(((char[int(len(char)*5/lines)+i] >> j)&mask)==mask):
								buf.append(1)
							else:
								buf.append(0)
			for j in range(4*h):
				buf.append(0)

		elif lines == 7:
			for i in range(int(len(char)/lines)):
					for j in range(8):
							if(((char[i] >> j)&mask)==mask):
								buf.append(1)
							else:
								buf.append(0)
					for j in range(8):
							if(((char[int(len(char)/lines)+i] >> j)&mask)==mask):
								buf.append(1)
							else:
								buf.append(0)

					for j in range(8):
							if(((char[int(len(char)*2/lines)+i] >> j)&mask)==mask):
								buf.append(1)
							else:
								buf.append(0)
					for j in range(8):
							if(((char[int(len(char)*3/lines)+i] >> j)&mask)==mask):
								buf.append(1)
							else:
								buf.append(0)

					for j in range(8):
							if(((char[int(len(char)*4/lines)+i] >> j)&mask)==mask):
								buf.append(1)
							else:
								buf.append(0)

					for j in range(8):
							if(((char[int(len(char)*5/lines)+i] >> j)&mask)==mask):
								buf.append(1)
							else:
								buf.append(0)

					for j in range(h-48):
							if(((char[int(len(char)*6/lines)+i] >> j)&mask)==mask):
								buf.append(1)
							else:
								buf.append(0)
			for j in range(4*h):
				buf.append(0)

		elif lines == 8:
			for i in range(int(len(char)/lines)):
					for j in range(8):
							if(((char[i] >> j)&mask)==mask):
								buf.append(1)
							else:
								buf.append(0)
					for j in range(8):
							if(((char[int(len(char)/lines)+i] >> j)&mask)==mask):
								buf.append(1)
							else:
								buf.append(0)

					for j in range(8):
							if(((char[int(len(char)*2/lines)+i] >> j)&mask)==mask):
								buf.append(1)
							else:
								buf.append(0)
					for j in range(8):
							if(((char[int(len(char)*3/lines)+i] >> j)&mask)==mask):
								buf.append(1)
							else:
								buf.append(0)

					for j in range(8):
							if(((char[int(len(char)*4/lines)+i] >> j)&mask)==mask):
								buf.append(1)
							else:
								buf.append(0)
					for j in range(8):
							if(((char[int(len(char)*5/lines)+i] >> j)&mask)==mask):
								buf.append(1)
							else:
								buf.append(0)
					for j in range(8):
							if(((char[int(len(char)*6/lines)+i] >> j)&mask)==mask):
								buf.append(1)
							else:
								buf.append(0)
					for j in range(h-56):
							if(((char[int(len(char)*7/lines)+i] >> j)&mask)==mask):
								buf.append(1)
							else:
								buf.append(0)
			for j in range(4*h):
				buf.append(0)

	remainder = (len(buf)/h) % 4

	if remainder != 0:

		for i in range(int(h*remainder)):
			buf.append(0)

#	print(len(buf)/h)
	max = (b - a + 1) * 4
#	print(max)

	for i in range((max - int(len(buf)/h))*h):
		buf.append(0)
#	print(message)
#	print(len(buf)/h)
#	print(max)


	for i in range(int((len(buf)/h)/4)):
		k=4*h*i
		for j in range(h):
			if buf[k+j]==1 and buf[k+j+h]==1:
				data(0xFF)
			elif buf[k+j]==0 and buf[k+j+h]==1:
				data(0x0F)
			elif buf[k+j]==1 and buf[k+j+h]==0:
				data(0xF0)

			else:
				data(0x00)

			if buf[k+j+2*h]==1 and buf[k+j+3*h]==1:
				data(0xFF)

			elif buf[k+j+2*h]==0 and buf[k+j+3*h]==1:
				data(0x0F)
			elif buf[k+j+2*h]==1 and buf[k+j+3*h]==0:
				data(0xF0)

			else:
				data(0x00)

def volume():
 	oled_string_vol(0x37,0x54,0x06,0x3D,56,volfont,"-39")

def oled_string1():

	input = "CamillaDSP"
	oled_string(0x1D,0x34,0x04,0x17,20,font3,input)

def oled_string2():
	oled_string(0x1D,0x34,0x18,0x2B,20,font3,str("96000 Hz"))

def oled_string3():
	oled_string(0x1D,0x37,0x2C,0x3F,20,font3,"RUNNING")

def dB():
	oled_string(0x56,0x5C,0x1F,0x32,20,font3,"dB")

# Initialize display
def oled_init():
	set_sleep_mode(0xAE)
	set_command_lock(0x12)
	set_display_clock_oscillator_frequency(0xA0)
	set_multiplex_ratio(0x3F)
	set_display_offset(0x00)
	function_selection(0x01)
	set_display_start_line(0x00)
	set_remap(0x15,0x11)
	master_contrast_control(0x0F)
	set_contrast_control(0x9F)
	set_phase_length(0xE2)
	set_precharge_voltage(0x17)
	enable_external_vsl(0xA0,0xFD)
	set_vcomh_voltage(0x04)
	display_mode(0xA6)
	exit_partial_display()
	display_enhancement(0xA2)
	set_gpio(0x00)
	default_grayscale_command()
	set_second_precharge_period(0x08)
	set_sleep_mode(0xAF)
	clearpixel()

#volfont is 56 pixels high
volfont = [
	#0 ' ' (40 pixels wide)
        [0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00], 

	#280 '-' (40 pixels wide)
	[0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x3E, 0x3E, 0x3E, 0x3E, 0x3E, 0x3E, 0x3E, 0x3E, 0x3E, 0x3E, 0x3E, 0x3E, 0x3E, 0x3E, 0x3E, 0x3E, 0x3E, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00], 

	#560 '0' (40 pixels wide)
	[0x00, 0x00, 0x00, 0x00, 0x80, 0xC0, 0xF0, 0xF8, 0xF8, 0xFC, 0xFE, 0x7E, 0x3E, 0x3F, 0x1F, 0x1F, 0x1F, 0x1F, 0x1F, 0x1F, 0x1F, 0x3F, 0x3E, 0x7E, 0xFE, 0xFC, 0xF8, 0xF8, 0xF0, 0xC0, 0x80, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
	0x00, 0xC0, 0xF8, 0xFE, 0xFF, 0xFF, 0x7F, 0x0F, 0x03, 0x01, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x01, 0x03, 0x0F, 0x7F, 0xFF, 0xFF, 0xFE, 0xF8, 0x80, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
	0xF0, 0xFF, 0xFF, 0xFF, 0xFF, 0x0F, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x0F, 0xFF, 0xFF, 0xFF, 0xFF, 0xF0, 0x00, 0x00, 0x00, 0x00, 0x00, 
	0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0x00, 0x00, 0x00, 0x00, 0x00, 
	0x0F, 0xFF, 0xFF, 0xFF, 0xFF, 0xF0, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0xF0, 0xFF, 0xFF, 0xFF, 0xFF, 0x0F, 0x00, 0x00, 0x00, 0x00, 0x00, 
	0x00, 0x03, 0x1F, 0xFF, 0xFF, 0xFF, 0xFE, 0xF0, 0xC0, 0x80, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x80, 0xC0, 0xF0, 0xFE, 0xFF, 0xFF, 0x7F, 0x1F, 0x01, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
	0x00, 0x00, 0x00, 0x00, 0x01, 0x07, 0x0F, 0x1F, 0x1F, 0x3F, 0x3F, 0x7E, 0x7C, 0xFC, 0xF8, 0xF8, 0xF8, 0xF8, 0xF8, 0xF8, 0xF8, 0xFC, 0x7C, 0x7E, 0x7F, 0x3F, 0x1F, 0x1F, 0x0F, 0x03, 0x01, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00], 

	#840 '1' (40 pixels wide)
	[0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x80, 0xE0, 0xFE, 0xFE, 0xFE, 0xFE, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
	0x00, 0x00, 0x00, 0x00, 0x00, 0x78, 0x78, 0x78, 0x78, 0x78, 0x78, 0x7C, 0x7C, 0x7C, 0x7E, 0x7E, 0x7F, 0x7F, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x7F, 0x7F, 0x7F, 0x7F, 0x7F, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00], 

	#1120 '2' (40 pixels wide)
	[0x00, 0x00, 0x00, 0x00, 0x00, 0xC0, 0xE0, 0xF0, 0xF8, 0xF8, 0xFC, 0x7E, 0x3E, 0x3E, 0x1F, 0x1F, 0x1F, 0x1F, 0x1F, 0x1F, 0x1F, 0x1F, 0x1F, 0x1F, 0x3E, 0x3E, 0x7E, 0xFC, 0xFC, 0xF8, 0xF0, 0xE0, 0xC0, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
	0x00, 0x00, 0xC0, 0xFC, 0xFF, 0xFF, 0xFF, 0x7F, 0x07, 0x01, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x01, 0x07, 0xFF, 0xFF, 0xFF, 0xFF, 0xF8, 0x00, 0x00, 0x00, 0x00, 0x00, 
	0x00, 0x00, 0x03, 0x03, 0x03, 0x03, 0x03, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0xC0, 0xF0, 0xFF, 0xFF, 0xFF, 0x7F, 0x07, 0x00, 0x00, 0x00, 0x00, 0x00, 
	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x80, 0x80, 0xC0, 0xE0, 0xE0, 0xF0, 0xF8, 0xF8, 0xFC, 0x7E, 0x3F, 0x3F, 0x1F, 0x0F, 0x03, 0x01, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x80, 0xC0, 0xE0, 0xE0, 0xF0, 0xF8, 0xFC, 0x7C, 0x7E, 0x3F, 0x1F, 0x1F, 0x0F, 0x07, 0x07, 0x03, 0x03, 0x01, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
	0x00, 0x00, 0xC0, 0xF8, 0xFC, 0xFE, 0xFF, 0x3F, 0x0F, 0x07, 0x03, 0x01, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
	0x00, 0x7E, 0x7F, 0x7F, 0x7F, 0x7F, 0x7F, 0x7C, 0x7C, 0x7C, 0x7C, 0x7C, 0x7C, 0x7C, 0x7C, 0x7C, 0x7C, 0x7C, 0x7C, 0x7C, 0x7C, 0x7C, 0x7C, 0x7C, 0x7C, 0x7C, 0x7C, 0x7C, 0x7C, 0x7C, 0x7C, 0x7C, 0x7C, 0x7C, 0x7C, 0x00, 0x00, 0x00, 0x00, 0x00], 

	#1400 '3' (40 pixels wide)
	[0x00, 0x00, 0x00, 0x00, 0x80, 0xC0, 0xE0, 0xF0, 0xF8, 0xFC, 0x7C, 0x7E, 0x3E, 0x3E, 0x1F, 0x1F, 0x1F, 0x1F, 0x1F, 0x1F, 0x1F, 0x1F, 0x1F, 0x3E, 0x3E, 0x7E, 0xFC, 0xFC, 0xF8, 0xF0, 0xE0, 0xC0, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
	0x00, 0x00, 0xF0, 0xFE, 0xFF, 0xFF, 0xFF, 0x1F, 0x03, 0x01, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x01, 0x07, 0xFF, 0xFF, 0xFF, 0xFF, 0xFC, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
	0x00, 0x00, 0x01, 0x01, 0x01, 0x01, 0x01, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x80, 0x80, 0xC0, 0xF0, 0xFC, 0xFF, 0x7F, 0x3F, 0x1F, 0x03, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x1E, 0x1E, 0x1E, 0x1E, 0x1E, 0x1E, 0x1E, 0x1E, 0x1F, 0x3F, 0x3F, 0x7F, 0xFB, 0xFB, 0xF1, 0xF0, 0xE0, 0xC0, 0x80, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
	0x80, 0x80, 0x80, 0x80, 0x80, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x01, 0x03, 0x0F, 0xFF, 0xFF, 0xFF, 0xFE, 0xF0, 0x00, 0x00, 0x00, 0x00, 0x00, 
	0x07, 0x3F, 0xFF, 0xFF, 0xFF, 0xFF, 0xF0, 0x80, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x80, 0xC0, 0xF8, 0xFF, 0xFF, 0xFF, 0x3F, 0x07, 0x00, 0x00, 0x00, 0x00, 0x00, 
	0x00, 0x00, 0x00, 0x03, 0x07, 0x0F, 0x1F, 0x1F, 0x3F, 0x3E, 0x7E, 0x7C, 0x7C, 0xF8, 0xF8, 0xF8, 0xF8, 0xF8, 0xF8, 0xF8, 0xF8, 0xF8, 0x78, 0x7C, 0x7C, 0x3E, 0x3F, 0x1F, 0x1F, 0x0F, 0x07, 0x03, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00], 

	#1680 '4' (40 pixels wide)
	[0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x80, 0xC0, 0xF0, 0xF8, 0xFE, 0xFE, 0xFE, 0xFE, 0xFE, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0xC0, 0xE0, 0xF8, 0xFC, 0xFE, 0x3F, 0x1F, 0x07, 0x03, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x80, 0xC0, 0xF0, 0xF8, 0xFE, 0xFF, 0x3F, 0x1F, 0x07, 0x01, 0x00, 0x00, 0x00, 0x00, 0x00, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
	0x00, 0x00, 0x00, 0x00, 0x80, 0xE0, 0xF0, 0xFC, 0xFE, 0x7F, 0x3F, 0x0F, 0x07, 0x01, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
	0xE0, 0xF8, 0xFC, 0xFF, 0xFF, 0xFF, 0xEF, 0xE3, 0xE1, 0xE0, 0xE0, 0xE0, 0xE0, 0xE0, 0xE0, 0xE0, 0xE0, 0xE0, 0xE0, 0xE0, 0xE0, 0xE0, 0xE0, 0xE0, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xE0, 0xE0, 0xE0, 0xE0, 0xE0, 0xE0, 0xE0, 0x00, 0x00, 0x00, 0x00, 
	0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x00, 0x00, 0x00, 0x00, 
	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x7F, 0x7F, 0x7F, 0x7F, 0x7F, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00], 

	#1960 '5' (40 pixels wide)
	[0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0xF8, 0xFE, 0xFE, 0xFE, 0x3E, 0x3E, 0x3E, 0x3E, 0x3E, 0x3E, 0x3E, 0x3E, 0x3E, 0x3E, 0x3E, 0x3E, 0x3E, 0x3E, 0x3E, 0x3E, 0x3E, 0x3E, 0x3E, 0x3E, 0x3E, 0x3E, 0x3E, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
	0x00, 0x00, 0x00, 0x00, 0x00, 0xFE, 0xFF, 0xFF, 0xFF, 0x07, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
	0x00, 0x00, 0x00, 0x80, 0xFF, 0xFF, 0xFF, 0xFF, 0x83, 0xC0, 0xC0, 0xE0, 0xE0, 0xE0, 0xE0, 0xF0, 0xF0, 0xF0, 0xF0, 0xF0, 0xF0, 0xF0, 0xF0, 0xE0, 0xE0, 0xE0, 0xC0, 0xC0, 0x80, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
	0x00, 0x00, 0x20, 0x3F, 0x3F, 0x3F, 0x3F, 0x1F, 0x0F, 0x07, 0x07, 0x03, 0x03, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x03, 0x03, 0x03, 0x07, 0x0F, 0x1F, 0x7F, 0xFF, 0xFE, 0xFC, 0xF8, 0xC0, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x01, 0xFF, 0xFF, 0xFF, 0xFF, 0xFE, 0x00, 0x00, 0x00, 0x00, 0x00, 
	0x00, 0x1E, 0xFE, 0xFE, 0xFE, 0xFE, 0xF0, 0xC0, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x80, 0xE0, 0xFC, 0xFF, 0xFF, 0xFF, 0x3F, 0x03, 0x00, 0x00, 0x00, 0x00, 0x00, 
	0x00, 0x00, 0x00, 0x01, 0x07, 0x0F, 0x0F, 0x1F, 0x3F, 0x3E, 0x7C, 0x7C, 0x78, 0xF8, 0xF8, 0xF8, 0xF8, 0xF8, 0xF8, 0xF8, 0xF8, 0xF8, 0x7C, 0x7C, 0x7E, 0x3E, 0x3F, 0x1F, 0x1F, 0x0F, 0x07, 0x01, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00], 

	#2240 '6' (40 pixels wide)
	[0x00, 0x00, 0x00, 0x00, 0x00, 0x80, 0xC0, 0xE0, 0xF0, 0xF8, 0xFC, 0xFC, 0x7E, 0x3E, 0x3E, 0x1F, 0x1F, 0x1F, 0x1F, 0x1F, 0x1F, 0x1F, 0x1F, 0x1F, 0x3E, 0x3E, 0x7E, 0xFC, 0xF8, 0xF8, 0xF0, 0xE0, 0x80, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
	0x00, 0x00, 0xC0, 0xF8, 0xFE, 0xFF, 0xFF, 0x3F, 0x0F, 0x03, 0x01, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x01, 0x07, 0x1F, 0x1F, 0x1F, 0x1F, 0x1C, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
	0x00, 0xFE, 0xFF, 0xFF, 0xFF, 0xFF, 0x01, 0x00, 0x00, 0x80, 0x80, 0xC0, 0xC0, 0xE0, 0xE0, 0xE0, 0xF0, 0xF0, 0xF0, 0xF0, 0xF0, 0xF0, 0xE0, 0xE0, 0xE0, 0xE0, 0xC0, 0x80, 0x80, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
	0xF8, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFC, 0xFE, 0x3F, 0x1F, 0x0F, 0x07, 0x03, 0x03, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x03, 0x03, 0x03, 0x07, 0x0F, 0x1F, 0x7F, 0xFF, 0xFE, 0xFC, 0xF0, 0xC0, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
	0x03, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0x9F, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x03, 0xFF, 0xFF, 0xFF, 0xFF, 0xFC, 0x00, 0x00, 0x00, 0x00, 0x00, 
	0x00, 0x03, 0x1F, 0x7F, 0xFF, 0xFF, 0xFF, 0xF0, 0xC0, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x80, 0xE0, 0xF8, 0xFF, 0xFF, 0xFF, 0x3F, 0x03, 0x00, 0x00, 0x00, 0x00, 0x00, 
	0x00, 0x00, 0x00, 0x00, 0x01, 0x03, 0x07, 0x1F, 0x1F, 0x3F, 0x3E, 0x7C, 0x7C, 0x78, 0xF8, 0xF8, 0xF8, 0xF8, 0xF8, 0xF8, 0xF8, 0xF8, 0xF8, 0x7C, 0x7C, 0x7E, 0x3F, 0x3F, 0x1F, 0x0F, 0x07, 0x03, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00], 

	#2520 '7' (40 pixels wide)
	[0x00, 0x3E, 0x3E, 0x3E, 0x3E, 0x3E, 0x3E, 0x3E, 0x3E, 0x3E, 0x3E, 0x3E, 0x3E, 0x3E, 0x3E, 0x3E, 0x3E, 0x3E, 0x3E, 0x3E, 0x3E, 0x3E, 0x3E, 0x3E, 0x3E, 0x3E, 0x3E, 0x3E, 0x3E, 0xFE, 0xFE, 0xFE, 0xFE, 0xFE, 0x7E, 0x00, 0x00, 0x00, 0x00, 0x00, 
	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x80, 0xE0, 0xF0, 0xFC, 0xFE, 0x7F, 0x1F, 0x0F, 0x03, 0x01, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x80, 0xE0, 0xF0, 0xFC, 0xFF, 0xFF, 0x3F, 0x0F, 0x03, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0xC0, 0xF0, 0xFE, 0xFF, 0xFF, 0x3F, 0x0F, 0x03, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0xC0, 0xF8, 0xFE, 0xFF, 0xFF, 0x7F, 0x0F, 0x01, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0xE0, 0xFE, 0xFF, 0xFF, 0xFF, 0x3F, 0x03, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x40, 0x7C, 0x7F, 0x7F, 0x7F, 0x7F, 0x0F, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00], 

	#2800 '8' (40 pixels wide)
	[0x00, 0x00, 0x00, 0x00, 0xC0, 0xE0, 0xF0, 0xF8, 0xFC, 0xFC, 0x7E, 0x3E, 0x3E, 0x1F, 0x1F, 0x1F, 0x1F, 0x1F, 0x1F, 0x1F, 0x1F, 0x1F, 0x3E, 0x3E, 0x7E, 0x7C, 0xFC, 0xF8, 0xF0, 0xE0, 0xC0, 0x80, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
	0x00, 0x00, 0xF8, 0xFF, 0xFF, 0xFF, 0xFF, 0x07, 0x01, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x01, 0x07, 0xFF, 0xFF, 0xFF, 0xFF, 0xFC, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
	0x00, 0x00, 0x03, 0x1F, 0x3F, 0x7F, 0xFF, 0xFC, 0xF0, 0xE0, 0xC0, 0x80, 0x80, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x80, 0x80, 0xC0, 0xC0, 0xE0, 0xF8, 0xFE, 0xFF, 0x7F, 0x3F, 0x0F, 0x03, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
	0x00, 0x00, 0x80, 0xC0, 0xE0, 0xF0, 0xF8, 0xF9, 0x7D, 0x3F, 0x3F, 0x1F, 0x1F, 0x1F, 0x0F, 0x0F, 0x0F, 0x0F, 0x0F, 0x0F, 0x0F, 0x0F, 0x0F, 0x1F, 0x1F, 0x3F, 0x3D, 0x7D, 0xFC, 0xF8, 0xF0, 0xF0, 0xE0, 0xC0, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
	0xF0, 0xFE, 0xFF, 0xFF, 0xFF, 0x0F, 0x03, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x01, 0x0F, 0xFF, 0xFF, 0xFF, 0xFF, 0xF0, 0x00, 0x00, 0x00, 0x00, 
	0x07, 0x3F, 0xFF, 0xFF, 0xFF, 0xF8, 0xC0, 0x80, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x80, 0xE0, 0xF8, 0xFF, 0xFF, 0xFF, 0x7F, 0x07, 0x00, 0x00, 0x00, 0x00, 
	0x00, 0x00, 0x00, 0x03, 0x07, 0x0F, 0x0F, 0x1F, 0x3F, 0x3E, 0x7C, 0x7C, 0x78, 0xF8, 0xF8, 0xF8, 0xF8, 0xF8, 0xF8, 0xF8, 0xF8, 0xF8, 0xF8, 0x7C, 0x7C, 0x7E, 0x3E, 0x3F, 0x1F, 0x1F, 0x0F, 0x07, 0x03, 0x01, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00], 

	#3080 '9' (40 pixels wide)
	[0x00, 0x00, 0x00, 0x00, 0xC0, 0xE0, 0xF0, 0xF8, 0xFC, 0xFC, 0x7E, 0x3E, 0x3E, 0x1F, 0x1F, 0x1F, 0x1F, 0x1F, 0x1F, 0x1F, 0x1F, 0x1F, 0x3E, 0x3E, 0x7E, 0xFC, 0xFC, 0xF8, 0xF0, 0xE0, 0xC0, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
	0x00, 0xC0, 0xFC, 0xFF, 0xFF, 0xFF, 0x1F, 0x07, 0x01, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x01, 0x03, 0x1F, 0xFF, 0xFF, 0xFF, 0xFC, 0xE0, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
	0x00, 0x7F, 0xFF, 0xFF, 0xFF, 0xFF, 0xC0, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x80, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFC, 0x00, 0x00, 0x00, 0x00, 0x00, 
	0x00, 0x00, 0x03, 0x0F, 0x3F, 0x7F, 0xFF, 0xFE, 0xF8, 0xF0, 0xE0, 0xC0, 0xC0, 0xC0, 0x80, 0x80, 0x80, 0x80, 0x80, 0x80, 0x80, 0xC0, 0xC0, 0xC0, 0xE0, 0xF0, 0xF8, 0xFE, 0x3F, 0x1F, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0x00, 0x00, 0x00, 0x00, 0x00, 
	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x01, 0x01, 0x03, 0x07, 0x07, 0x07, 0x0F, 0x0F, 0x0F, 0x0F, 0x0F, 0x0F, 0x0F, 0x07, 0x07, 0x07, 0x03, 0x03, 0x01, 0x00, 0x00, 0x00, 0xE0, 0xFF, 0xFF, 0xFF, 0xFF, 0x07, 0x00, 0x00, 0x00, 0x00, 0x00, 
	0x00, 0x00, 0x38, 0xF8, 0xF8, 0xF8, 0xF8, 0xC0, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x80, 0xC0, 0xF8, 0xFE, 0xFF, 0xFF, 0x3F, 0x0F, 0x01, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
	0x00, 0x00, 0x00, 0x01, 0x07, 0x0F, 0x1F, 0x1F, 0x3F, 0x7E, 0x7C, 0x7C, 0xF8, 0xF8, 0xF8, 0xF8, 0xF8, 0xF8, 0xF8, 0xF8, 0xF8, 0x7C, 0x7C, 0x7E, 0x3F, 0x1F, 0x1F, 0x0F, 0x07, 0x03, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00],

	# '+' (40 pixels wide)
	[0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x0F, 0x0F, 0x0F, 0x0F, 0x0F, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x3E, 0x3E, 0x3E, 0x3E, 0x3E, 0x3E, 0x3E, 0x3E, 0x3E, 0x3E, 0x3E, 0x3E, 0x3E, 0x3E, 0x3E, 0x3E, 0x3E, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0xF8, 0xF8, 0xF8, 0xF8, 0xF8, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00], 
	]

font2 = [
	 #0 ' ' (4 pixels wide)
	[0x00, 0x00, 0x00, 0x00,
	0x00, 0x00, 0x00, 0x00],

	 #8 '!' (1 pixels wide)
	[0xFE, 
	0x0D], 

	 #10 '"' (4 pixels wide)
	[0x0E, 0x00, 0x00, 0x0E, 
	0x00, 0x00, 0x00, 0x00], 

	 #18 '#' (8 pixels wide)
	[0x80, 0x90, 0xF8, 0x96, 0x90, 0xF8, 0x96, 0x90, 
	0x00, 0x07, 0x00, 0x00, 0x07, 0x00, 0x00, 0x00], 

	 #34 '$' (6 pixels wide)
	[0x1C, 0x24, 0x62, 0xFF, 0xC2, 0x86, 
	0x0C, 0x08, 0x08, 0x3F, 0x08, 0x07], 

	 #46 '%' (10 pixels wide)
	[0x1C, 0x22, 0x22, 0xA2, 0x5C, 0x30, 0x8C, 0x82, 0x80, 0x00, 
	0x00, 0x08, 0x06, 0x01, 0x00, 0x07, 0x08, 0x08, 0x08, 0x07], 

	 #66 '&' (11 pixels wide)
	[0x80, 0x5C, 0x62, 0x22, 0x62, 0xDC, 0x80, 0x00, 0x80, 0x70, 0x00, 
	0x07, 0x0C, 0x08, 0x08, 0x08, 0x08, 0x05, 0x03, 0x05, 0x08, 0x08], 

	 #88 ' ' ' (1 pixels wide)
	[0x0E, 
	0x00], 

	 #90 '(' (3 pixels wide)
	[0xE0, 0x18, 0x06, 
	0x03, 0x0C, 0x30], 

	 #96 ')' (3 pixels wide)
	[0x06, 0x18, 0xE0, 
	0x30, 0x0C, 0x03], 

	 #102 '*' (5 pixels wide)
	[0x08, 0x70, 0x1E, 0x70, 0x08, 
	0x00, 0x00, 0x00, 0x00, 0x00], 

	 #112 '+' (7 pixels wide)
	[0x80, 0x80, 0x80, 0xF0, 0x80, 0x80, 0x80, 
	0x00, 0x00, 0x00, 0x07, 0x00, 0x00, 0x00], 

	 #126 ',' (2 pixels wide)
	[0x00, 0x00, 
	0x30, 0x0C], 

	 #130 '-' (4 pixels wide)
	[0x80, 0x80, 0x80, 0x80, 
	0x00, 0x00, 0x00, 0x00], 

	 #138 '.' (1 pixels wide)
	[0x00, 
	0x0C], 

	 #140 '/' (6 pixels wide)
	[0x00, 0x00, 0x80, 0xE0, 0x1C, 0x02, 
	0x20, 0x1C, 0x03, 0x00, 0x00, 0x00], 

	 #152 '0' (6 pixels wide)
	[0xF8, 0x04, 0x02, 0x02, 0x06, 0xF8, 
	0x03, 0x0C, 0x08, 0x08, 0x04, 0x03], 

	 #164 '1' (3 pixels wide)
	[0x08, 0x04, 0xFE, 
	0x00, 0x00, 0x0F], 

	 #170 '2' (6 pixels wide)
	[0x04, 0x02, 0x02, 0x82, 0x46, 0x3C, 
	0x0E, 0x0B, 0x09, 0x08, 0x08, 0x08], 

	 #182 '3' (6 pixels wide)
	[0x04, 0x42, 0x42, 0x42, 0xA6, 0x9C, 
	0x0C, 0x08, 0x08, 0x08, 0x04, 0x07], 

	 #194 '4' (7 pixels wide)
	[0x80, 0xC0, 0x60, 0x18, 0x0C, 0xFE, 0x00, 
	0x01, 0x01, 0x01, 0x01, 0x01, 0x0F, 0x01], 

	 #208 '5' (6 pixels wide)
	[0x3E, 0x22, 0x22, 0x22, 0x42, 0x80, 
	0x0C, 0x08, 0x08, 0x08, 0x04, 0x03], 

	 #220 '6' (6 pixels wide)
	[0xF0, 0x4C, 0x22, 0x22, 0x62, 0xC0, 
	0x03, 0x04, 0x08, 0x08, 0x0C, 0x03], 

	 #232 '7' (6 pixels wide)
	[0x02, 0x02, 0x82, 0x72, 0x0E, 0x06, 
	0x00, 0x0C, 0x03, 0x00, 0x00, 0x00], 

	 #244 '8' (6 pixels wide)
	[0x9C, 0xE6, 0x42, 0x42, 0xE6, 0xBC, 
	0x07, 0x0C, 0x08, 0x08, 0x0C, 0x07], 

	 #256 '9' (6 pixels wide)
	[0x78, 0xC6, 0x82, 0x82, 0x46, 0xF8, 
	0x00, 0x08, 0x08, 0x08, 0x06, 0x01], 

	 #268 ':' (1 pixels wide)
	[0x30, 
	0x0C], 

	 #270 ';' (2 pixels wide)
	[0x00, 0x30, 
	0x30, 0x0C], 

	 #274 '<' (6 pixels wide)
	[0x80, 0x80, 0x40, 0x60, 0x20, 0x10, 
	0x00, 0x01, 0x01, 0x02, 0x02, 0x04], 

	 #286 '=' (7 pixels wide)
	[0x40, 0x40, 0x40, 0x40, 0x40, 0x40, 0x40, 
	0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02], 

	 #300 '>' (6 pixels wide)
	[0x10, 0x20, 0x60, 0x40, 0x80, 0x80, 
	0x04, 0x02, 0x02, 0x01, 0x01, 0x00], 

	 #312 '?' (5 pixels wide)
	[0x06, 0x82, 0x42, 0x22, 0x1C, 
	0x00, 0x0D, 0x00, 0x00, 0x00], 

	 #322 '#' (12 pixels wide)
	[0xE0, 0x18, 0x04, 0xE4, 0x32, 0x12, 0x12, 0xF2, 0x02, 0x04, 0x08, 0xF0, 
	0x03, 0x06, 0x08, 0x19, 0x12, 0x12, 0x11, 0x13, 0x1A, 0x02, 0x01, 0x00], 

	 #346 'A' (10 pixels wide)
	[0x00, 0x00, 0xC0, 0x38, 0x0E, 0x0E, 0x78, 0xC0, 0x00, 0x00, 
	0x08, 0x0F, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x0F, 0x08], 

	 #366 'B' (6 pixels wide)
	[0xFE, 0x42, 0x42, 0x42, 0xA6, 0x9C, 
	0x0F, 0x08, 0x08, 0x08, 0x0C, 0x07], 

	 #378 'C' (7 pixels wide)
	[0xF0, 0x0C, 0x04, 0x02, 0x02, 0x02, 0x06, 
	0x01, 0x06, 0x0C, 0x08, 0x08, 0x08, 0x0C], 

	 #392 'D' (9 pixels wide)
	[0xFE, 0x02, 0x02, 0x02, 0x02, 0x02, 0x04, 0x0C, 0xF0, 
	0x0F, 0x08, 0x08, 0x08, 0x08, 0x08, 0x04, 0x02, 0x01], 

	 #410 'E' (6 pixels wide)
	[0xFE, 0x42, 0x42, 0x42, 0x42, 0x02, 
	0x0F, 0x08, 0x08, 0x08, 0x08, 0x08], 

	 #422 'F' (5 pixels wide)
	[0xFE, 0x42, 0x42, 0x42, 0x42, 
	0x0F, 0x00, 0x00, 0x00, 0x00], 

	 #432 'G' (8 pixels wide)
	[0xF0, 0x08, 0x04, 0x02, 0x02, 0x42, 0x42, 0xC6, 
	0x01, 0x06, 0x04, 0x08, 0x08, 0x08, 0x08, 0x07], 

	 #448 'H' (8 pixels wide)
	[0xFE, 0x40, 0x40, 0x40, 0x40, 0x40, 0x40, 0xFE, 
	0x0F, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x0F], 

	 #464 'I' (1 pixels wide)
	[0xFE, 
	0x0F], 

	 #466 'J' (4 pixels wide)
	[0x00, 0x00, 0x00, 0xFE, 
	0x08, 0x08, 0x0C, 0x03], 

	 #474 'K' (8 pixels wide)
	[0xFE, 0x40, 0xE0, 0x90, 0x08, 0x04, 0x02, 0x00, 
	0x0F, 0x00, 0x00, 0x01, 0x03, 0x06, 0x0C, 0x08], 

	 #490 'L' (5 pixels wide)
	[0xFE, 0x00, 0x00, 0x00, 0x00, 
	0x0F, 0x08, 0x08, 0x08, 0x08], 

	 #500 'M' (10 pixels wide)
	[0xFE, 0x0E, 0x70, 0xC0, 0x00, 0x00, 0xC0, 0x70, 0x0E, 0xFE, 
	0x0F, 0x00, 0x00, 0x01, 0x06, 0x0E, 0x01, 0x00, 0x00, 0x0F], 

	 #520 'N' (8 pixels wide)
	[0xFE, 0x0E, 0x18, 0x60, 0xC0, 0x00, 0x00, 0xFE, 
	0x0F, 0x00, 0x00, 0x00, 0x00, 0x03, 0x0E, 0x0F], 

	 #536 'O' (9 pixels wide)
	[0xF0, 0x0C, 0x06, 0x02, 0x02, 0x02, 0x06, 0x0C, 0xF0, 
	0x01, 0x06, 0x0C, 0x08, 0x08, 0x08, 0x0C, 0x06, 0x01], 

	 #554 'P' (6 pixels wide)
	[0xFE, 0x82, 0x82, 0x82, 0x46, 0x3C, 
	0x0F, 0x00, 0x00, 0x00, 0x00, 0x00], 

	 #566 'Q' (10 pixels wide)
	[0xF0, 0x1C, 0x04, 0x02, 0x02, 0x02, 0x06, 0x0C, 0xF8, 0x00, 
	0x01, 0x07, 0x0C, 0x08, 0x08, 0x08, 0x0C, 0x1E, 0x13, 0x10], 

	 #586 'R' (8 pixels wide)
	[0xFE, 0x42, 0x42, 0x42, 0xC2, 0x26, 0x1C, 0x00, 
	0x0F, 0x00, 0x00, 0x00, 0x00, 0x03, 0x0E, 0x08], 

	 #602 'S' (6 pixels wide)
	[0x1C, 0x26, 0x42, 0x42, 0x82, 0x06, 
	0x0C, 0x08, 0x08, 0x08, 0x0C, 0x07], 

	 #614 'T' (7 pixels wide)
	[0x02, 0x02, 0x02, 0xFE, 0x02, 0x02, 0x02, 
	0x00, 0x00, 0x00, 0x0F, 0x00, 0x00, 0x00], 

	 #628 'U' (8 pixels wide)
	[0xFE, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0xFE, 
	0x03, 0x04, 0x08, 0x08, 0x08, 0x08, 0x04, 0x03], 

	 #644 'V' (9 pixels wide)
	[0x02, 0x1E, 0xF0, 0x80, 0x00, 0x80, 0xF0, 0x1C, 0x02, 
	0x00, 0x00, 0x00, 0x07, 0x08, 0x07, 0x00, 0x00, 0x00], 

	 #662 'W' (14 pixels wide)
	[0x06, 0x3E, 0xE0, 0x00, 0x00, 0xE0, 0x1E, 0x1E, 0xF0, 0x00, 0x00, 0xE0, 0x3C, 0x06, 
	0x00, 0x00, 0x03, 0x0E, 0x0F, 0x01, 0x00, 0x00, 0x00, 0x0F, 0x0E, 0x03, 0x00, 0x00], 

	 #690 'X' (9 pixels wide)
	[0x02, 0x06, 0x1C, 0xB0, 0x40, 0xB0, 0x1C, 0x06, 0x02, 
	0x08, 0x0C, 0x07, 0x01, 0x00, 0x01, 0x07, 0x0C, 0x08], 

	 #708 'Y' (8 pixels wide)
	[0x02, 0x0E, 0x18, 0x60, 0x80, 0x60, 0x1C, 0x02, 
	0x00, 0x00, 0x00, 0x00, 0x0F, 0x00, 0x00, 0x00], 

	 #724 'Z' (9 pixels wide)
	[0x00, 0x02, 0x02, 0x82, 0xE2, 0x32, 0x1A, 0x06, 0x02, 
	0x08, 0x0C, 0x0B, 0x09, 0x08, 0x08, 0x08, 0x08, 0x08], 

	 #742 '[' (3 pixels wide)
	[0xFE, 0x02, 0x02, 
	0x3F, 0x20, 0x20], 

	 #748 '\' (6 pixels wide)
	[0x02, 0x1C, 0xE0, 0x80, 0x00, 0x00, 
	0x00, 0x00, 0x00, 0x03, 0x1C, 0x20], 

	 #760 ']' (3 pixels wide)
	[0x02, 0x02, 0xFE, 
	0x20, 0x20, 0x3F], 

	 #766 '^' (7 pixels wide)
	[0x40, 0x30, 0x0C, 0x06, 0x18, 0x30, 0x40, 
	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00], 

	 #780 '_' (6 pixels wide)
	[0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
	0x20, 0x20, 0x20, 0x20, 0x20, 0x20], 

	 #792 '`' (2 pixels wide)
	[0x02, 0x04, 
	0x00, 0x00], 

	 #796 'a' (6 pixels wide)
	[0x00, 0x30, 0x90, 0x90, 0x90, 0xE0, 
	0x07, 0x09, 0x08, 0x08, 0x04, 0x0F], 

	 #808 'b' (7 pixels wide)
	[0xFE, 0x20, 0x10, 0x10, 0x10, 0x30, 0xC0, 
	0x0F, 0x04, 0x08, 0x08, 0x08, 0x04, 0x03], 

	 #822 'c' (5 pixels wide)
	[0xC0, 0x20, 0x10, 0x10, 0x10, 
	0x03, 0x0C, 0x08, 0x08, 0x08], 

	 #832 'd' (7 pixels wide)
	[0xC0, 0x20, 0x10, 0x10, 0x10, 0x20, 0xFE, 
	0x03, 0x0C, 0x08, 0x08, 0x08, 0x04, 0x0F], 

	 #846 'e' (6 pixels wide)
	[0xC0, 0xA0, 0x90, 0x90, 0x90, 0xE0, 
	0x07, 0x0C, 0x08, 0x08, 0x0C, 0x00], 

	 #858 'f' (4 pixels wide)
	[0x10, 0xFC, 0x12, 0x12, 
	0x00, 0x0F, 0x00, 0x00], 

	 #866 'g' (7 pixels wide)
	[0xC0, 0x20, 0x10, 0x10, 0x10, 0x20, 0xF0, 
	0x03, 0x4C, 0x48, 0x48, 0x48, 0x24, 0x1F], 

	 #880 'h' (6 pixels wide)
	[0xFE, 0x20, 0x10, 0x10, 0x30, 0xE0, 
	0x0F, 0x00, 0x00, 0x00, 0x00, 0x0F], 

	 #892 'i' (1 pixels wide)
	[0xF2, 
	0x0F], 

	 #894 'j' (4 pixels wide)
	[0x00, 0x00, 0x00, 0xF2, 
	0x40, 0x40, 0x60, 0x3F], 

	 #902 'k' (6 pixels wide)
	[0xFE, 0x80, 0xC0, 0x60, 0x30, 0x10, 
	0x0F, 0x01, 0x03, 0x06, 0x0C, 0x08], 

	 #914 'l' (1 pixels wide)
	[0xFE, 
	0x0F], 

	 #916 'm' (11 pixels wide)
	[0xF0, 0x20, 0x10, 0x10, 0x30, 0xE0, 0x20, 0x10, 0x10, 0x30, 0xE0, 
	0x0F, 0x00, 0x00, 0x00, 0x00, 0x0F, 0x00, 0x00, 0x00, 0x00, 0x0F], 

	 #938 'n' (6 pixels wide)
	[0xF0, 0x20, 0x10, 0x10, 0x30, 0xE0, 
	0x0F, 0x00, 0x00, 0x00, 0x00, 0x0F], 

	 #950 'o' (7 pixels wide)
	[0xC0, 0x20, 0x10, 0x10, 0x10, 0x20, 0xC0, 
	0x03, 0x04, 0x08, 0x08, 0x08, 0x04, 0x03], 

	 #964 'p' (7 pixels wide)
	[0xF0, 0x20, 0x10, 0x10, 0x10, 0x30, 0xC0, 
	0x7F, 0x04, 0x08, 0x08, 0x08, 0x04, 0x03], 

	 #978 'q' (7 pixels wide)
	[0xC0, 0x20, 0x10, 0x10, 0x10, 0x20, 0xF0, 
	0x03, 0x04, 0x08, 0x08, 0x08, 0x04, 0x7F], 

	 #992 'r' (4 pixels wide)
	[0xF0, 0x20, 0x10, 0x10, 
	0x0F, 0x00, 0x00, 0x00], 

	 #1000 's' (4 pixels wide)
	[0xE0, 0x90, 0x10, 0x10, 
	0x08, 0x08, 0x09, 0x07], 

	 #1008 't' (4 pixels wide)
	[0x10, 0xFC, 0x10, 0x10, 
	0x00, 0x07, 0x08, 0x08], 

	 #1016 'u' (6 pixels wide)
	[0xF0, 0x00, 0x00, 0x00, 0x00, 0xF0, 
	0x07, 0x0C, 0x08, 0x08, 0x04, 0x0F], 

	 #1028 'v' (7 pixels wide)
	[0x10, 0xE0, 0x00, 0x00, 0x00, 0xE0, 0x10, 
	0x00, 0x00, 0x07, 0x08, 0x07, 0x00, 0x00], 

	 #1042 'w' (11 pixels wide)
	[0x30, 0xE0, 0x00, 0x00, 0xC0, 0x30, 0xE0, 0x00, 0x00, 0xE0, 0x30, 
	0x00, 0x01, 0x0F, 0x0E, 0x01, 0x00, 0x01, 0x0E, 0x0E, 0x01, 0x00], 

	 #1064 'x' (7 pixels wide)
	[0x10, 0x30, 0xC0, 0x80, 0xC0, 0x30, 0x10, 
	0x08, 0x0C, 0x03, 0x01, 0x03, 0x0C, 0x08], 

	 #1078 'y' (7 pixels wide)
	[0x10, 0xE0, 0x00, 0x00, 0x00, 0xE0, 0x10, 
	0x40, 0x40, 0x27, 0x18, 0x07, 0x00, 0x00], 

	 #1092 'z' (7 pixels wide)
	[0x10, 0x10, 0x10, 0x90, 0xD0, 0x30, 0x10, 
	0x08, 0x0C, 0x0B, 0x09, 0x08, 0x08, 0x08], 

	 #1106 '{' (3 pixels wide)
	[0x80, 0x7C, 0x02, 
	0x00, 0x1F, 0x20], 

	 #1112 '|' (1 pixels wide)
	[0xFE, 
	0x7F], 

	 #1114 '}' (3 pixels wide)
	[0x02, 0x7C, 0x80, 
	0x20, 0x1F, 0x00], 

	 #1120 '~' (7 pixels wide)
	[0x80, 0x40, 0x40, 0xC0, 0x80, 0x80, 0x40, 
	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00], 


	]

font3 = [
	#0 ' ' (4 pixels wide)
	[0x00, 0x00, 0x00, 0x00, 
	0x00, 0x00, 0x00, 0x00, 
	0x00, 0x00, 0x00, 0x00], 

	#12 '!' (1 pixels wide)
	[0xFC, 
	0xDF, 
	0x00], 

	#15 '"' (4 pixels wide)
	[0x04, 0xFC, 0x00, 0xFC, 
	0x00, 0x00, 0x00, 0x00, 
	0x00, 0x00, 0x00, 0x00], 

	#27 '#' (9 pixels wide)
	[0x00, 0x40, 0xC0, 0x7C, 0x40, 0x40, 0x40, 0xFC, 0x40, 
	0x08, 0xE8, 0x1F, 0x08, 0x08, 0xC8, 0x3F, 0x08, 0x08, 
	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00], 

	#54 '$' (8 pixels wide)
	[0x70, 0x88, 0x04, 0xFF, 0x04, 0x04, 0x18, 0x20, 
	0x30, 0x40, 0x81, 0xFF, 0x81, 0x82, 0x42, 0x3C, 
	0x00, 0x00, 0x00, 0x03, 0x00, 0x00, 0x00, 0x00], 

	#78 '%' (13 pixels wide)
	[0xF8, 0x04, 0x04, 0x04, 0xF8, 0x00, 0x00, 0x80, 0x60, 0x10, 0x0C, 0x04, 0x00, 
	0x00, 0x81, 0xC1, 0x21, 0x18, 0x04, 0x03, 0x00, 0x7C, 0x82, 0x82, 0x82, 0x7C, 
	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00], 

	#117 '&' (12 pixels wide)
	[0x00, 0x00, 0x38, 0xC4, 0x84, 0x84, 0x44, 0x38, 0x00, 0x00, 0x00, 0x00, 
	0x3C, 0x42, 0x81, 0x80, 0x81, 0x82, 0x84, 0x48, 0x30, 0x4C, 0x82, 0x80, 
	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00], 

	#153 ' ' ' (2 pixels wide)
	[0xFC, 0xFC, 
	0x00, 0x00, 
	0x00, 0x00], 

	#159 '(' (3 pixels wide)
	[0xC0, 0x30, 0x0C, 
	0x7F, 0x80, 0x00, 
	0x00, 0x01, 0x06], 

	#168 ')' (3 pixels wide)
	[0x0C, 0x70, 0x80, 
	0x00, 0x80, 0x7F, 
	0x06, 0x01, 0x00], 

	#177 '*' (6 pixels wide)
	[0x10, 0xA0, 0x60, 0x7C, 0xA0, 0x10, 
	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
	0x00, 0x00, 0x00, 0x00, 0x00, 0x00], 

	#195 '+' (7 pixels wide)
	[0x00, 0x00, 0x00, 0xE0, 0x00, 0x00, 0x00, 
	0x01, 0x01, 0x01, 0x0F, 0x01, 0x01, 0x01, 
	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00], 

	#216 ',' (1 pixels wide)
	[0x00, 
	0xC0, 
	0x07], 

	#219 '-' (4 pixels wide)
	[0x00, 0x00, 0x00, 0x00, 
	0x04, 0x04, 0x04, 0x04, 
	0x00, 0x00, 0x00, 0x00], 

	#231 '.' (1 pixels wide)
	[0x00, 
	0xC0, 
	0x00], 

	#234 '/' (7 pixels wide)
	[0x00, 0x00, 0x00, 0x00, 0xC0, 0x30, 0x0C, 
	0x00, 0xC0, 0x30, 0x0E, 0x01, 0x00, 0x00, 
	0x06, 0x01, 0x00, 0x00, 0x00, 0x00, 0x00], 

	#255 '0' (9 pixels wide)
	[0xE0, 0x18, 0x08, 0x04, 0x04, 0x04, 0x08, 0x10, 0xE0, 
	0x1F, 0x60, 0x80, 0x80, 0x80, 0x80, 0x40, 0x60, 0x1F, 
	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00], 

	#282 '1' (4 pixels wide)
	[0x20, 0x20, 0x30, 0xFC, 
	0x00, 0x00, 0x00, 0xFF, 
	0x00, 0x00, 0x00, 0x00], 

	#294 '2' (8 pixels wide)
	[0x70, 0x08, 0x04, 0x04, 0x04, 0x04, 0x08, 0xF0, 
	0xE0, 0x90, 0x88, 0x84, 0x84, 0x82, 0x81, 0x80, 
	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00], 

	#318 '3' (9 pixels wide)
	[0x00, 0x30, 0x08, 0x04, 0x04, 0x04, 0x04, 0x88, 0x70, 
	0x10, 0x60, 0x40, 0x80, 0x81, 0x81, 0x81, 0x42, 0x3C, 
	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00], 

	#345 '4' (9 pixels wide)
	[0x00, 0x00, 0x00, 0xC0, 0x20, 0x18, 0xFC, 0x00, 0x00, 
	0x0C, 0x0A, 0x09, 0x08, 0x08, 0x08, 0xFF, 0x08, 0x08, 
	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00], 

	#372 '5' (9 pixels wide)
	[0x00, 0xC0, 0x3C, 0x84, 0x84, 0x84, 0x84, 0x04, 0x04, 
	0x10, 0x31, 0x41, 0x80, 0x80, 0x80, 0x80, 0x41, 0x3E, 
	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00], 

	#399 '6' (8 pixels wide)
	[0xF0, 0x08, 0x84, 0x84, 0x84, 0x84, 0x08, 0x10, 
	0x3F, 0x41, 0x80, 0x80, 0x80, 0x80, 0x41, 0x3E, 
	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00], 

	#426 '7' (9 pixels wide)
	[0x04, 0x04, 0x04, 0x04, 0x04, 0x84, 0x64, 0x14, 0x0C, 
	0x00, 0x00, 0x80, 0xF8, 0x06, 0x01, 0x00, 0x00, 0x00, 
	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00], 

	#453 '8' (9 pixels wide)
	[0x00, 0x70, 0x88, 0x04, 0x04, 0x04, 0x88, 0x70, 0x00, 
	0x3C, 0x42, 0x81, 0x81, 0x81, 0x81, 0x81, 0x42, 0x3C, 
	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00], 

	#480 '9' (9 pixels wide)
	[0xF0, 0x08, 0x04, 0x04, 0x04, 0x04, 0x04, 0x18, 0xE0, 
	0x21, 0x42, 0x84, 0x84, 0x84, 0x84, 0x42, 0x22, 0x1F, 
	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00], 

	#507 ':' (1 pixels wide)
	[0x80, 
	0xC1, 
	0x00], 

	#510 ';' (1 pixels wide)
	[0x80, 
	0xC1, 
	0x07], 

	#513 '<' (9 pixels wide)
	[0x00, 0x00, 0x80, 0x80, 0x40, 0x40, 0x20, 0x20, 0x30, 
	0x03, 0x03, 0x04, 0x04, 0x08, 0x08, 0x10, 0x10, 0x30, 
	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00], 

	#540 '=' (7 pixels wide)
	[0x80, 0x80, 0x80, 0x80, 0x80, 0x80, 0x80, 
	0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 
	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00], 

	#561 '>' (10 pixels wide)
	[0x10, 0x20, 0x20, 0x40, 0x40, 0x80, 0x80, 0x80, 0x00, 0x00, 
	0x20, 0x10, 0x10, 0x08, 0x08, 0x04, 0x04, 0x04, 0x03, 0x03, 
	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00], 

	#591 '?' (8 pixels wide)
	[0x30, 0x08, 0x04, 0x04, 0x04, 0x04, 0x88, 0x70, 
	0x00, 0x00, 0x00, 0xDC, 0x02, 0x01, 0x00, 0x00, 
	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00], 

	#615 '@' (14 pixels wide)
	[0x80, 0x60, 0x10, 0x08, 0x88, 0x44, 0x24, 0x24, 0x24, 0xC4, 0x68, 0x08, 0x10, 0xE0, 
	0x07, 0x18, 0x20, 0x40, 0x47, 0x88, 0x90, 0x90, 0x88, 0x8F, 0x90, 0x50, 0x0C, 0x03, 
	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00], 

	#657 'A' (11 pixels wide)
	[0x00, 0x00, 0x00, 0xC0, 0x30, 0x0C, 0x30, 0xC0, 0x00, 0x00, 0x00, 
	0xC0, 0x38, 0x0F, 0x08, 0x08, 0x08, 0x08, 0x08, 0x0F, 0x38, 0xC0, 
	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00], 

	#696 'B' (10 pixels wide)
	[0xFC, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x88, 0x70, 0x00, 
	0xFF, 0x81, 0x81, 0x81, 0x81, 0x81, 0x81, 0x81, 0x42, 0x3C, 
	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00], 

	#726 'C' (11 pixels wide)
	[0xC0, 0x30, 0x08, 0x04, 0x04, 0x04, 0x04, 0x04, 0x08, 0x08, 0x30, 
	0x0F, 0x30, 0x40, 0x40, 0x80, 0x80, 0x80, 0x80, 0x40, 0x60, 0x18, 
	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00], 

	#762 'D' (11 pixels wide)
	[0xFC, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x08, 0x30, 0xC0, 
	0xFF, 0x80, 0x80, 0x80, 0x80, 0x80, 0x80, 0x80, 0x40, 0x30, 0x0F, 
	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00], 

	#795 'E' (9 pixels wide)
	[0xFC, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 
	0xFF, 0x81, 0x81, 0x81, 0x81, 0x81, 0x81, 0x81, 0x80, 
	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00], 

	#822 'F' (8 pixels wide)
	[0xFC, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 
	0xFF, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x00, 
	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00], 

	#846 'G' (12 pixels wide)
	[0xC0, 0x30, 0x08, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x08, 0x30, 0x40, 
	0x0F, 0x30, 0x40, 0x40, 0x80, 0x80, 0x82, 0x82, 0x82, 0x42, 0x22, 0xFE, 
	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00], 

	#882 'H' (10 pixels wide)
	[0xFC, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0xFC, 
	0xFF, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0xFF, 
	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00], 

	#912 'I' (1 pixels wide)
	[0xFC, 
	0xFF, 
	0x00], 

	#915 'J' (7 pixels wide)
	[0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0xFC, 
	0x30, 0x40, 0x80, 0x80, 0x80, 0x40, 0x3F, 
	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00], 

	#936 'K' (10 pixels wide)
	[0xFC, 0x00, 0x00, 0x80, 0x40, 0x20, 0x10, 0x08, 0x04, 0x04, 
	0xFF, 0x02, 0x01, 0x01, 0x02, 0x04, 0x18, 0x20, 0x40, 0x80, 
	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00], 

	#966 'L' (8 pixels wide)
	[0xFC, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
	0xFF, 0x80, 0x80, 0x80, 0x80, 0x80, 0x80, 0x80, 
	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00], 

	#990 'M' (13 pixels wide)
	[0xFC, 0x18, 0x60, 0x80, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0xE0, 0x18, 0xFC, 
	0xFF, 0x00, 0x00, 0x03, 0x0C, 0x30, 0xC0, 0x70, 0x0C, 0x03, 0x00, 0x00, 0xFF, 
	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00], 

	#1029 'N' (10 pixels wide)
	[0xFC, 0x18, 0x20, 0xC0, 0x80, 0x00, 0x00, 0x00, 0x00, 0xFC, 
	0xFF, 0x00, 0x00, 0x00, 0x01, 0x06, 0x0C, 0x10, 0x60, 0xFF, 
	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00], 

	#1059 'O' (13 pixels wide)
	[0xC0, 0x30, 0x08, 0x08, 0x04, 0x04, 0x04, 0x04, 0x04, 0x08, 0x08, 0x30, 0xC0, 
	0x0F, 0x30, 0x40, 0x40, 0x80, 0x80, 0x80, 0x80, 0x80, 0x40, 0x40, 0x30, 0x0F, 
	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00], 

	#1098 'P' (9 pixels wide)
	[0xFC, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x08, 0xF0, 
	0xFF, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x01, 0x00, 
	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00], 

	#1125 'Q' (13 pixels wide)
	[0xC0, 0x30, 0x08, 0x08, 0x04, 0x04, 0x04, 0x04, 0x04, 0x08, 0x08, 0x30, 0xC0, 
	0x0F, 0x30, 0x40, 0x40, 0x80, 0x80, 0x80, 0x80, 0xA0, 0x40, 0x40, 0xB0, 0x0F, 
	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x01], 

	#1164 'R' (10 pixels wide)
	[0xFC, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x08, 0xF0, 
	0xFF, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x05, 0xF8, 
	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00], 

	#1194 'S' (10 pixels wide)
	[0x70, 0x88, 0x04, 0x04, 0x04, 0x04, 0x04, 0x08, 0x18, 0x20, 
	0x38, 0x40, 0x81, 0x81, 0x81, 0x81, 0x82, 0x82, 0x46, 0x38, 
	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00], 

	#1224 'T' (9 pixels wide)
	[0x04, 0x04, 0x04, 0x04, 0xFC, 0x04, 0x04, 0x04, 0x04, 
	0x00, 0x00, 0x00, 0x00, 0xFF, 0x00, 0x00, 0x00, 0x00, 
	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00], 

	#1251 'U' (10 pixels wide)
	[0xFC, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0xFC, 
	0x3F, 0x40, 0x80, 0x80, 0x80, 0x80, 0x80, 0x80, 0x40, 0x3F, 
	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00], 

	#1281 'V' (12 pixels wide)
	[0x04, 0x1C, 0xE0, 0x00, 0x00, 0x00, 0x00, 0x00, 0x80, 0x70, 0x0C, 0x02, 
	0x00, 0x00, 0x00, 0x07, 0x38, 0xC0, 0x60, 0x1C, 0x03, 0x00, 0x00, 0x00, 
	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00], 

	#1317 'W' (17 pixels wide)
	[0x04, 0x3C, 0xC0, 0x00, 0x00, 0x00, 0x00, 0xF0, 0x0C, 0x38, 0xC0, 0x00, 0x00, 0x00, 0x80, 0x70, 0x0C, 
	0x00, 0x00, 0x03, 0x3C, 0xC0, 0x38, 0x07, 0x00, 0x00, 0x00, 0x03, 0x3C, 0xC0, 0x38, 0x07, 0x00, 0x00, 
	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00], 

	#1368 'X' (11 pixels wide)
	[0x04, 0x04, 0x18, 0x20, 0xC0, 0x00, 0x80, 0x40, 0x30, 0x08, 0x04, 
	0x80, 0x80, 0x60, 0x10, 0x0C, 0x03, 0x06, 0x08, 0x30, 0x40, 0x80, 
	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00], 

	#1401 'Y' (11 pixels wide)
	[0x04, 0x0C, 0x30, 0x40, 0x80, 0x00, 0x80, 0x40, 0x30, 0x0C, 0x04, 
	0x00, 0x00, 0x00, 0x00, 0x01, 0xFE, 0x01, 0x00, 0x00, 0x00, 0x00, 
	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00], 

	#1434 'Z' (10 pixels wide)
	[0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0xC4, 0x24, 0x1C, 0x04, 
	0x80, 0xE0, 0x90, 0x8C, 0x82, 0x81, 0x80, 0x80, 0x80, 0x80, 
	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00], 

	#1464 '[' (3 pixels wide)
	[0xFC, 0x04, 0x04, 
	0xFF, 0x00, 0x00, 
	0x03, 0x02, 0x02], 

	#1473 '\' (8 pixels wide)
	[0x04, 0x18, 0xE0, 0x00, 0x00, 0x00, 0x00, 0x00, 
	0x00, 0x00, 0x00, 0x07, 0x38, 0xC0, 0x00, 0x00, 
	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x07, 0x04], 

	#1497 ']' (3 pixels wide)
	[0x04, 0x04, 0xFC, 
	0x00, 0x00, 0xFF, 
	0x02, 0x02, 0x03], 

	#1506 '^' (9 pixels wide)
	[0x80, 0x40, 0x30, 0x0C, 0x04, 0x18, 0x60, 0x80, 0x00, 
	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x01, 
	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00], 

	#1533 '_' (10 pixels wide)
	[0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
	0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04], 

	#1563 '`' (3 pixels wide)
	[0x02, 0x04, 0x08, 
	0x00, 0x00, 0x00, 
	0x00, 0x00, 0x00], 

	#1572 'a' (9 pixels wide)
	[0x00, 0x80, 0x40, 0x40, 0x40, 0x40, 0x40, 0x80, 0x00, 
	0x71, 0x89, 0x84, 0x84, 0x84, 0x44, 0x44, 0x7F, 0x80, 
	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00], 

	#1599 'b' (8 pixels wide)
	[0xFC, 0x80, 0x40, 0x40, 0x40, 0x40, 0x80, 0x00, 
	0xFF, 0x40, 0x80, 0x80, 0x80, 0x80, 0x60, 0x1F, 
	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00], 

	#1623 'c' (8 pixels wide)
	[0x00, 0x80, 0x40, 0x40, 0x40, 0x40, 0x80, 0x00, 
	0x1E, 0x61, 0x80, 0x80, 0x80, 0x80, 0x40, 0x21, 
	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00], 

	#1647 'd' (9 pixels wide)
	[0x00, 0x80, 0x40, 0x40, 0x40, 0x40, 0x80, 0x80, 0xFC, 
	0x1E, 0x61, 0x40, 0x80, 0x80, 0x80, 0x40, 0x40, 0xFF, 
	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00], 

	#1674 'e' (9 pixels wide)
	[0x00, 0x80, 0x80, 0x40, 0x40, 0x40, 0x80, 0x80, 0x00, 
	0x1E, 0x65, 0x44, 0x84, 0x84, 0x84, 0x44, 0x67, 0x14, 
	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00], 

	#1701 'f' (4 pixels wide)
	[0x40, 0xF8, 0x44, 0x44, 
	0x00, 0xFF, 0x00, 0x00, 
	0x00, 0x00, 0x00, 0x00], 

	#1713 'g' (9 pixels wide)
	[0x00, 0x80, 0x80, 0x40, 0x40, 0x40, 0x80, 0x80, 0xC0, 
	0x1E, 0x61, 0x80, 0x80, 0x80, 0x80, 0x40, 0x40, 0xFF, 
	0x02, 0x06, 0x08, 0x08, 0x08, 0x08, 0x08, 0x04, 0x03], 

	#1740 'h' (7 pixels wide)
	[0xFC, 0x80, 0x40, 0x40, 0x40, 0x40, 0x80, 
	0xFF, 0x00, 0x00, 0x00, 0x00, 0x00, 0xFF, 
	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00], 

	#1761 'i' (1 pixels wide)
	[0xCC, 
	0xFF, 
	0x00], 

	#1764 'j' (2 pixels wide)
	[0x00, 0xCC, 
	0x00, 0xFF, 
	0x04, 0x03], 

	#1770 'k' (8 pixels wide)
	[0xFC, 0x00, 0x00, 0x00, 0x00, 0x80, 0x40, 0x20, 
	0xFF, 0x04, 0x04, 0x06, 0x19, 0x20, 0xC0, 0x80, 
	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00], 

	#1794 'l' (1 pixels wide)
	[0xFC, 
	0xFF, 
	0x00], 

	#1797 'm' (13 pixels wide)
	[0xC0, 0x80, 0x40, 0x40, 0x40, 0x40, 0x80, 0x80, 0x40, 0x40, 0x40, 0x40, 0x80, 
	0xFF, 0x00, 0x00, 0x00, 0x00, 0x00, 0xFF, 0x00, 0x00, 0x00, 0x00, 0x00, 0xFF, 
	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00], 

	#1836 'n' (7 pixels wide)
	[0xC0, 0x80, 0x40, 0x40, 0x40, 0x40, 0x80, 
	0xFF, 0x00, 0x00, 0x00, 0x00, 0x00, 0xFF, 
	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00], 

	#1857 'o' (9 pixels wide)
	[0x00, 0x80, 0x80, 0x40, 0x40, 0x40, 0x80, 0x80, 0x00, 
	0x1E, 0x61, 0x80, 0x80, 0x80, 0x80, 0x80, 0x61, 0x1E, 
	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00], 

	#1884 'p' (8 pixels wide)
	[0xC0, 0x80, 0x40, 0x40, 0x40, 0x40, 0x80, 0x00, 
	0xFF, 0x40, 0x80, 0x80, 0x80, 0x80, 0x61, 0x1E, 
	0x0F, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00], 

	#1908 'q' (9 pixels wide)
	[0x00, 0x80, 0x80, 0x40, 0x40, 0x40, 0x80, 0x80, 0xC0, 
	0x1E, 0x61, 0x80, 0x80, 0x80, 0x80, 0x80, 0x40, 0xFF, 
	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x0F], 

	#1935 'r' (4 pixels wide)
	[0xC0, 0x80, 0x40, 0x40, 
	0xFF, 0x00, 0x00, 0x00, 
	0x00, 0x00, 0x00, 0x00], 

	#1947 's' (8 pixels wide)
	[0x80, 0x40, 0x40, 0x40, 0x40, 0x40, 0x80, 0x00, 
	0x63, 0x44, 0x84, 0x84, 0x84, 0x88, 0x48, 0x31, 
	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00], 

	#1971 't' (4 pixels wide)
	[0x40, 0xF8, 0x40, 0x40, 
	0x00, 0x7F, 0x80, 0x80, 
	0x00, 0x00, 0x00, 0x00], 

	#1983 'u' (7 pixels wide)
	[0xC0, 0x00, 0x00, 0x00, 0x00, 0x00, 0xC0, 
	0x7F, 0x80, 0x80, 0x80, 0x80, 0x40, 0xFF, 
	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00], 

	#2004 'v' (9 pixels wide)
	[0x40, 0xC0, 0x00, 0x00, 0x00, 0x00, 0x00, 0x80, 0x40, 
	0x00, 0x01, 0x0E, 0x30, 0xC0, 0x30, 0x0E, 0x01, 0x00, 
	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00], 

	#2031 'w' (14 pixels wide)
	[0x40, 0x80, 0x00, 0x00, 0x00, 0x00, 0xC0, 0x80, 0x00, 0x00, 0x00, 0x00, 0xC0, 0x20, 
	0x00, 0x03, 0x1C, 0xE0, 0x70, 0x0E, 0x01, 0x03, 0x3C, 0xC0, 0x30, 0x0E, 0x01, 0x00, 
	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00], 

	#2073 'x' (9 pixels wide)
	[0x20, 0x40, 0x80, 0x00, 0x00, 0x00, 0x80, 0x40, 0x40, 
	0x80, 0xC0, 0x21, 0x12, 0x0C, 0x12, 0x21, 0x40, 0x80, 
	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00], 

	#2100 'y' (9 pixels wide)
	[0x40, 0xC0, 0x00, 0x00, 0x00, 0x00, 0x00, 0x80, 0x40, 
	0x00, 0x01, 0x0E, 0x70, 0x80, 0x60, 0x1C, 0x03, 0x00, 
	0x00, 0x08, 0x08, 0x04, 0x03, 0x00, 0x00, 0x00, 0x00], 

	#2127 'z' (8 pixels wide)
	[0x40, 0x40, 0x40, 0x40, 0x40, 0x40, 0xC0, 0x00, 
	0xC0, 0xA0, 0x90, 0x8C, 0x82, 0x81, 0x80, 0x80, 
	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00], 

	#2151 '{' (4 pixels wide)
	[0x00, 0xF8, 0x04, 0x04, 
	0x06, 0xF9, 0x00, 0x00, 
	0x00, 0x01, 0x02, 0x02], 

	#2163 '|' (1 pixels wide)
	[0xFC, 
	0xFF, 
	0x0F], 

	#2166 '}' (4 pixels wide)
	[0x04, 0x04, 0xF8, 0x00, 
	0x00, 0x00, 0xF9, 0x06, 
	0x02, 0x02, 0x01, 0x00], 

	#2178 '~' (10 pixels wide)
	[0x08, 0x04, 0x02, 0x02, 0x04, 0x04, 0x08, 0x08, 0x04, 0x02, 
	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00]

	]
# 5x7 font table
font1 = [
[0x00, 0x00, 0x00, 0x00, 0x00], # SPACE
[0x00, 0x00, 0x5F, 0x00, 0x00], # !
[0x00, 0x03, 0x00, 0x03, 0x00], # "
[0x14, 0x3E, 0x14, 0x3E, 0x14], # #
[0x24, 0x2A, 0x7F, 0x2A, 0x12], # $
[0x43, 0x33, 0x08, 0x66, 0x61], # %
[0x36, 0x49, 0x55, 0x22, 0x50], # &
[0x00, 0x05, 0x03, 0x00, 0x00], # '
[0x00, 0x1C, 0x22, 0x41, 0x00], # (
[0x00, 0x41, 0x22, 0x1C, 0x00], # )
[0x14, 0x08, 0x3E, 0x08, 0x14], # *
[0x08, 0x08, 0x3E, 0x08, 0x08], # +
[0x00, 0x50, 0x30, 0x00, 0x00], # ,
[0x08, 0x08, 0x08, 0x08, 0x08], # -
[0x00, 0x60, 0x60, 0x00, 0x00], # .
[0x20, 0x10, 0x08, 0x04, 0x02], # /
[0x3E, 0x51, 0x49, 0x45, 0x3E], # 0
[0x04, 0x02, 0x7F, 0x00, 0x00], # 1
[0x42, 0x61, 0x51, 0x49, 0x46], # 2
[0x22, 0x41, 0x49, 0x49, 0x36], # 3
[0x18, 0x14, 0x12, 0x7F, 0x10], # 4
[0x27, 0x45, 0x45, 0x45, 0x39], # 5
[0x3E, 0x49, 0x49, 0x49, 0x32], # 6
[0x01, 0x01, 0x71, 0x09, 0x07], # 7
[0x36, 0x49, 0x49, 0x49, 0x36], # 8
[0x26, 0x49, 0x49, 0x49, 0x3E], # 9
[0x00, 0x36, 0x36, 0x00, 0x00], # :
[0x00, 0x56, 0x36, 0x00, 0x00], # ;
[0x08, 0x14, 0x22, 0x41, 0x00], # <
[0x14, 0x14, 0x14, 0x14, 0x14], # =
[0x00, 0x41, 0x22, 0x14, 0x08], # >
[0x02, 0x01, 0x51, 0x09, 0x06], # ?
[0x3E, 0x41, 0x59, 0x55, 0x5E], # @
[0x7E, 0x09, 0x09, 0x09, 0x7E], # A
[0x7F, 0x49, 0x49, 0x49, 0x36], # B
[0x3E, 0x41, 0x41, 0x41, 0x22], # C
[0x7F, 0x41, 0x41, 0x41, 0x3E], # D
[0x7F, 0x49, 0x49, 0x49, 0x41], # E
[0x7F, 0x09, 0x09, 0x09, 0x01], # F
[0x3E, 0x41, 0x41, 0x49, 0x3A], # G
[0x7F, 0x08, 0x08, 0x08, 0x7F], # H
[0x00, 0x41, 0x7F, 0x41, 0x00], # I
[0x30, 0x40, 0x40, 0x40, 0x3F], # J
[0x7F, 0x08, 0x14, 0x22, 0x41], # K
[0x7F, 0x40, 0x40, 0x40, 0x40], # L
[0x7F, 0x02, 0x0C, 0x02, 0x7F], # M
[0x7F, 0x02, 0x04, 0x08, 0x7F], # N
[0x3E, 0x41, 0x41, 0x41, 0x3E], # O
[0x7F, 0x09, 0x09, 0x09, 0x06], # P
[0x1E, 0x21, 0x21, 0x21, 0x5E], # Q
[0x7F, 0x09, 0x09, 0x09, 0x76], # R
[0x26, 0x49, 0x49, 0x49, 0x32], # S
[0x01, 0x01, 0x7F, 0x01, 0x01], # T
[0x3F, 0x40, 0x40, 0x40, 0x3F], # U
[0x1F, 0x20, 0x40, 0x20, 0x1F], # V
[0x7F, 0x20, 0x10, 0x20, 0x7F], # W
[0x41, 0x22, 0x1C, 0x22, 0x41], # X
[0x07, 0x08, 0x70, 0x08, 0x07], # Y
[0x61, 0x51, 0x49, 0x45, 0x43], # Z
[0x00, 0x7F, 0x41, 0x00, 0x00], # [
[0x02, 0x04, 0x08, 0x10, 0x20], # \
[0x00, 0x00, 0x41, 0x7F, 0x00], # ]
[0x04, 0x02, 0x01, 0x02, 0x04], # ^
[0x40, 0x40, 0x40, 0x40, 0x40], # _
[0x00, 0x01, 0x02, 0x04, 0x00], # `
[0x20, 0x54, 0x54, 0x54, 0x78], # a
[0x7F, 0x44, 0x44, 0x44, 0x38], # b
[0x38, 0x44, 0x44, 0x44, 0x44], # c
[0x38, 0x44, 0x44, 0x44, 0x7F], # d
[0x38, 0x54, 0x54, 0x54, 0x18], # e
[0x04, 0x04, 0x7E, 0x05, 0x05], # f
[0x08, 0x54, 0x54, 0x54, 0x3C], # g
[0x7F, 0x08, 0x04, 0x04, 0x78], # h
[0x00, 0x44, 0x7D, 0x40, 0x00], # i
[0x20, 0x40, 0x44, 0x3D, 0x00], # j
[0x7F, 0x10, 0x28, 0x44, 0x00], # k
[0x00, 0x41, 0x7F, 0x40, 0x00], # l
[0x7C, 0x04, 0x78, 0x04, 0x78], # m
[0x7C, 0x08, 0x04, 0x04, 0x78], # n
[0x38, 0x44, 0x44, 0x44, 0x38], # o
[0x7C, 0x14, 0x14, 0x14, 0x08], # p
[0x08, 0x14, 0x14, 0x14, 0x7C], # q
[0x00, 0x7C, 0x08, 0x04, 0x04], # r
[0x48, 0x54, 0x54, 0x54, 0x20], # s
[0x04, 0x04, 0x3F, 0x44, 0x44], # t
[0x3C, 0x40, 0x40, 0x20, 0x7C], # u
[0x1C, 0x20, 0x40, 0x20, 0x1C], # v
[0x3C, 0x40, 0x30, 0x40, 0x3C], # w
[0x44, 0x28, 0x10, 0x28, 0x44], # x
[0x0C, 0x50, 0x50, 0x50, 0x3C], # y
[0x44, 0x64, 0x54, 0x4C, 0x44], # z
[0x00, 0x08, 0x36, 0x41, 0x41], # {
[0x00, 0x00, 0x7F, 0x00, 0x00], # |
[0x41, 0x41, 0x36, 0x08, 0x00], # }
[0x02, 0x01, 0x02, 0x04, 0x02]  # ~
]

if __name__ == '__main__':

  try:
    main()
  except KeyboardInterrupt:
    pass
  finally:
    clearpixel()
    GPIO.cleanup()
